@@ -14,9 +14,9 @@ The goal is to show the API in action.
 #include "config.h"
 
 #include <libssh/callbacks.h>
-#include <libssh/poll.h>
 #include <libssh/server.h>
 
+#include <poll.h>
 #ifdef HAVE_ARGP_H
 #include <argp.h>
 #endif
@@ -621,6 +621,7 @@ int main(int argc, char **argv) {
     ssh_session session;
     ssh_event event;
     struct sigaction sa;
+    int rc;
 
     /* Set up SIGCHLD handler. */
     sa.sa_handler = sigchld_handler;
@@ -631,8 +632,17 @@ int main(int argc, char **argv) {
         return 1;
     }
 
-    ssh_init();
+    rc = ssh_init();
+    if (rc < 0) {
+        fprintf(stderr, "ssh_init failed\n");
+        return 1;
+    }
+
     sshbind = ssh_bind_new();
+    if (sshbind == NULL) {
+        fprintf(stderr, "ssh_bind_new failed\n");
+        return 1;
+    }
 
 #ifdef HAVE_ARGP_H
     argp_parse(&argp, argc, argv, 0, 0, sshbind);
